# pymacaron-docker

Tools for packaging a PyMacaron microservice as a Docker image.

See more at [pymacaron.com](http://pymacaron.com/deploy.html)

## bin/pymdocker

Build a pymacaron docker image and/or push it to a docker repository. For
details:

```
pymdocker --help
```

## Author

Erwan Lemonnier<br/>
[github.com/pymacaron](https://github.com/pymacaron)</br>
[github.com/erwan-lemonnier](https://github.com/erwan-lemonnier)<br/>
[www.linkedin.com/in/erwan-lemonnier/](https://www.linkedin.com/in/erwan-lemonnier/)